@@ -11,7 +11,7 @@ our ($VERSION);
 use XSLoader ();
 
 BEGIN {
-    $VERSION = '0.11_02';
+    $VERSION = '0.12_01';
     XSLoader::load();
 }
 
@@ -31,6 +31,9 @@ CBOR::Free - Fast CBOR for everyone
 
     my $tagged = CBOR::Free::tag( 1, '2019-01-02T00:01:02Z' );
 
+Also see L<CBOR::Free::Decoder> for an object-oriented interface
+to the decoder.
+
 =head1 DESCRIPTION
 
 This library implements L<CBOR|https://tools.ietf.org/html/rfc7049>
@@ -48,7 +51,7 @@ please always check the changelog before upgrading.
 =head2 $cbor = encode( $DATA, %OPTS )
 
 Encodes a data structure or non-reference scalar to CBOR.
-The encoder recognizes and encodes integers, floats, binary and UTF-8
+The encoder recognizes and encodes integers, floats, byte and character
 strings, array and hash references, L<CBOR::Free::Tagged> instances,
 L<Types::Serialiser> booleans, and undef (encoded as null).
 
@@ -68,7 +71,7 @@ Notes on mapping Perl to CBOR:
 =over
 
 =item * The internal state of a defined Perl scalar (e.g., whether it’s an
-integer, float, binary string, or UTF-8 string) determines its CBOR
+integer, float, byte string, or character string) determines its CBOR
 encoding.
 
 =item * L<Types::Serialiser> booleans are encoded as CBOR booleans.
@@ -91,10 +94,10 @@ Notes on mapping CBOR to Perl:
 
 =over
 
-=item * CBOR UTF-8 strings become Perl UTF-8 strings. CBOR binary strings
-become Perl binary strings. (This may become configurable later.)
+=item * CBOR text strings become Perl character strings. CBOR binary strings
+become Perl byte strings. (This may become configurable later.)
 
-Note that invalid UTF-8 in a CBOR UTF-8 string is considered
+Note that invalid UTF-8 in a CBOR text string is considered
 invalid input and will thus prompt a thrown exception.
 
 =item * The only map keys that C<decode()> accepts are integers and strings.
@@ -103,7 +106,9 @@ An exception is thrown if the decoder finds anything else as a map key.
 =item * CBOR booleans become the corresponding L<Types::Serialiser> values.
 Both CBOR null and undefined become Perl undef.
 
-=item * Tags are IGNORED for now. (This may become configurable later.)
+=item * This function does not interpret tags; if you need that, look
+at L<CBOR::Free::Decoder>. Any tags that this function sees prompt a warning
+but are otherwise ignored.
 
 =back
 
@@ -116,9 +121,8 @@ C<encode()> receives.)
 =head1 BOOLEANS
 
 C<CBOR::Free::true()> and C<CBOR::Free::false()> are defined as
-convenience aliases for the equivalent L<Types::Serialiser> values.
-Note that there are no aliases for C<$Types::Serialiser::true> or
-C<$Types::Serialiser::false>.
+convenience aliases for the equivalent L<Types::Serialiser> functions.
+(Note that there are no equivalent scalar aliases.)
 
 =head1 FRACTIONAL (FLOATING-POINT) NUMBERS
 
@@ -161,6 +165,11 @@ CBOR::Free is pretty snappy. I find that it keeps pace with or
 surpasses L<CBOR::XS>, L<Cpanel::JSON::XS>, L<JSON::XS>, L<Sereal>,
 and L<Data::MessagePack>.
 
+It’s also quite light. Its only “heavy” dependency is
+L<Types::Serialiser>, which is only loaded when you actually need it.
+This keeps memory usage low for when, e.g., you’re using CBOR for
+IPC between Perl processes and have no need for true booleans.
+
 =head1 AUTHOR
 
 L<Gasper Software Consulting|http://gaspersoftware.com> (FELIPE)
